enviPathR.RdThe environmental pathway database (enviPath) is a key resource for the functional annotation and pathway prediction of microbial communities, providing knowledge on biotransformation pathways along with the chemical reactions and produced compounds. This package enables the programmatic access to enviPath by porting the database API from R.
enviPath front page: https://envipath.org/
legacy API docs: https://envipath.org/api/legacy/docs#/