epLogin lets you perform login to enviPath. An account is required to use the enviPath API.

epLogin(username, password)

Arguments

username

Character scalar. String specifying the username used to log into an enviPath personal account.

password

Character scalar. String specifying the password used to log into an enviPath personal account.

Value

A message upon successful login.

Examples

# Perform login
epLogin(username, password)
#> Hi nature lover, welcome to enviPath!