epLink.RdepLink returns mappings between enviPath object types.
epLink(from, to, init = NULL, pkg = NULL)Character scalar. String specifying the object type from
which mapping is performed.
Character scalar. String specifying the object type to which
mapping is performed.
Character vector. Vector of strings specifying the initial
values of from that should be mapped to to. When null, all
objects belonging to from in pkg are used.
(Default: NULL)
Character scalar. String specifying the unique identifier
of the package from which objects should be mapped When null, EAWAG-BBD is
used. (Default: NULL)
A data frame with links between from and to.
#> Hi nature lover, welcome to enviPath!
rxn_id <- "2b6bbcc5-77f4-4bed-92a9-731cdc978f6a"
epLink("reaction", "compound", rxn_id)
#> reaction compound
#> 1 2b6bbcc5-77f4-4bed-92a9-731cdc978f6a 7281d994-9f4a-4f7f-9e50-90b131c11da3
#> 2 2b6bbcc5-77f4-4bed-92a9-731cdc978f6a befe8eeb-e8f8-4b4a-90b1-d0584a75f8cb