epLogin.Rd
epLogin lets you perform login to enviPath. An account is required to use the enviPath API.
epLogin(username, password)
Character scalar. String specifying the username used to log into an enviPath personal account.
Character scalar
Character scalar. String specifying the password used to log into an enviPath personal account.
A message upon successful login.
# Perform login epLogin(username, password) #> Hi nature lover, welcome to enviPath!